@@ -49,6 +49,7 @@ const nsIDOMChromeWindow     = Components.interfaces.nsIDOMChromeWindow;
 const nsIDOMWindow           = Components.interfaces.nsIDOMWindow;
 const nsIFactory             = Components.interfaces.nsIFactory;
 const nsIFileURL             = Components.interfaces.nsIFileURL;
+const nsIJARURI              = Components.interfaces.nsIJARURI;
 const nsIHttpProtocolHandler = Components.interfaces.nsIHttpProtocolHandler;
 const nsIInterfaceRequestor  = Components.interfaces.nsIInterfaceRequestor;
 const nsIPrefBranch          = Components.interfaces.nsIPrefBranch;
@@ -203,14 +204,14 @@ function getMostRecentWindow(aType) {
   return wm.getMostRecentWindow(aType);
 }
 
-//@line 214 "/usr/obj/ports/mozilla-firefox-2.0.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 215 "/usr/obj/ports/mozilla-firefox-2.0.0.7/mozilla/browser/components/nsBrowserContentHandler.js"
 
 // this returns the most recent non-popup browser window
 function getMostRecentBrowserWindow() {
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 221 "/usr/obj/ports/mozilla-firefox-2.0.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 222 "/usr/obj/ports/mozilla-firefox-2.0.0.7/mozilla/browser/components/nsBrowserContentHandler.js"
   var win = wm.getMostRecentWindow("navigator:browser", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -223,7 +224,7 @@ function getMostRecentBrowserWindow() {
         win = nextWin;
     }
   }
-//@line 246 "/usr/obj/ports/mozilla-firefox-2.0.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 247 "/usr/obj/ports/mozilla-firefox-2.0.0.7/mozilla/browser/components/nsBrowserContentHandler.js"
 
   return win;
 }
@@ -411,12 +412,28 @@ var nsBrowserContentHandler = {
       // Handle the old preference dialog URL separately (bug 285416)
       if (chromeParam == "chrome://browser/content/pref/pref.xul") {
         openPreferences();
-      } else {
-        var features = "chrome,dialog=no,all" + this.getFeatures(cmdLine);
-        openWindow(null, chromeParam, "_blank", features, "");
-      }
+        cmdLine.preventDefault = true;
+      } else try {
+        // only load URIs which do not inherit chrome privs.
 
-      cmdLine.preventDefault = true;
+        // normally would call checkLoadURI(..., DISALLOW_SCRIPT_OR_DATA)
+        // for this, but in this context we crash when the security manager
+        // tries to throw an exception (no window object here). On the branch
+        // we need to simulate the important bits
+        var uri = resolveURIInternal(cmdLine, chromeParam);
+        while (uri instanceof nsIJARURI) {
+          // unpack to find the real scheme
+          uri = uri.JARFile;
+        }
+        if (!uri.schemeIs("javascript") && !uri.schemeIs("data")) {
+          var features = "chrome,dialog=no,all" + this.getFeatures(cmdLine);
+          openWindow(null, uri.spec, "_blank", features, "");
+          cmdLine.preventDefault = true;
+        }
+      }
+      catch (e) {
+        Components.utils.reportError(e);
+      }
     }
     if (cmdLine.handleFlag("preferences", false)) {
       openPreferences();
@@ -431,7 +448,7 @@ var nsBrowserContentHandler = {
       cmdLine.preventDefault = true;
     }
 
-//@line 466 "/usr/obj/ports/mozilla-firefox-2.0.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 483 "/usr/obj/ports/mozilla-firefox-2.0.0.7/mozilla/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -647,13 +664,13 @@ var nsDefaultCommandLineHandler = {
   // running and have already been handled. This is compared against uri's
   // opened using DDE on Win32 so we only open one of the requests.
   _handledURIs: [ ],
-//@line 684 "/usr/obj/ports/mozilla-firefox-2.0.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 701 "/usr/obj/ports/mozilla-firefox-2.0.0.7/mozilla/browser/components/nsBrowserContentHandler.js"
 
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
-//@line 710 "/usr/obj/ports/mozilla-firefox-2.0.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 727 "/usr/obj/ports/mozilla-firefox-2.0.0.7/mozilla/browser/components/nsBrowserContentHandler.js"
 
     try {
       var ar;
@@ -803,9 +820,9 @@ var Module = {
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 860 "/usr/obj/ports/mozilla-firefox-2.0.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 877 "/usr/obj/ports/mozilla-firefox-2.0.0.7/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("image/svg+xml");
-//@line 862 "/usr/obj/ports/mozilla-firefox-2.0.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 879 "/usr/obj/ports/mozilla-firefox-2.0.0.7/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
